@@ -26,7 +26,6 @@
 #include <Akonadi/AgentInstanceCreateJob>
 #include <Akonadi/AgentManager>
 #include <Akonadi/AgentTypeDialog>
-#include <Akonadi/Calendar/StandardCalendarActionManager>
 #include <Akonadi/CollectionDeleteJob>
 #include <Akonadi/CollectionFilterProxyModel>
 #include <Akonadi/CollectionIdentificationAttribute>
@@ -34,6 +33,7 @@
 #include <Akonadi/EntityDisplayAttribute>
 #include <Akonadi/EntityTreeModel>
 #include <Akonadi/EntityTreeView>
+#include <Akonadi/StandardCalendarActionManager>
 #include <PimCommonAkonadi/MailUtil>
 #include <PimCommonAkonadi/ManageServerSideSubscriptionJob>
 
@@ -252,7 +252,7 @@ public:
     QVariant data(const QModelIndex &index, int role) const override
     {
         if (!index.isValid()) {
-            return QVariant();
+            return {};
         }
         if (role == Qt::DecorationRole) {
             const Akonadi::Collection collection = CalendarSupport::collectionFromIndex(index);
@@ -309,7 +309,7 @@ public:
     }
 
 protected:
-    bool filterAcceptsRow(int row, const QModelIndex &sourceParent) const override
+    Q_REQUIRED_RESULT bool filterAcceptsRow(int row, const QModelIndex &sourceParent) const override
     {
         const QModelIndex sourceIndex = sourceModel()->index(row, 0, sourceParent);
         Q_ASSERT(sourceIndex.isValid());
@@ -324,7 +324,7 @@ protected:
         return true;
     }
 
-    QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (role == Qt::ToolTipRole) {
             const Akonadi::Collection col = CalendarSupport::collectionFromIndex(index);
@@ -344,7 +344,7 @@ public:
     }
 
 protected:
-    bool checkChildren(const QModelIndex &index, int role, const QVariant &value) const
+    Q_REQUIRED_RESULT bool checkChildren(const QModelIndex &index, int role, const QVariant &value) const
     {
         const QModelIndex sourceIndex = mapToSource(index);
         for (int i = 0; i < sourceModel()->rowCount(sourceIndex); ++i) {
