@@ -13,8 +13,8 @@
 #include <CalendarSupport/CalendarSingleton>
 #include <CalendarSupport/Utils>
 
-#include <Akonadi/Calendar/IncidenceChanger>
 #include <Akonadi/Collection>
+#include <Akonadi/IncidenceChanger>
 #include <Akonadi/ItemFetchScope>
 
 #include <KCalUtils/IncidenceFormatter>
@@ -60,9 +60,7 @@ TodoSummaryWidget::TodoSummaryWidget(TodoPlugin *plugin, QWidget *parent)
     updateView();
 }
 
-TodoSummaryWidget::~TodoSummaryWidget()
-{
-}
+TodoSummaryWidget::~TodoSummaryWidget() = default;
 
 void TodoSummaryWidget::updateView()
 {
